Learn R Programming

onlineforecast (version 1.0.1)

onlineforecast: Functions for online forecasting

Description

Functions for online forecasting

Arguments

Details

This package provides functions to for setting up forecast models which run in an online setting, e.g. like demand, solar and wind power forecasts updated regularly - often hourly, and forecasts up to 48 hours ahead.

See the website https://onlineforecasting.org for more information.